import typer
import premovr.game_interfaces.lichess_api as chess_api
from premovr.hardware_interfaces.http_server_api import Board

app = typer.Typer()

@app.command('display')
def display_board():
    '''Displays a dummy chess board'''
    print(chess_api.game)

@app.command('server')
def server():
    '''Some options related to the server'''
    b = Board('192.168.1.1')
    print(b.heartbeat())

def main():
    app()

if __name__ == "__main__":
    main()



import requests
from typing import Dict

class Board:
    def __init__(self, ip_address: str):
        '''Initialize the board'''
        self.__ip_address = ip_address
    
    def heartbeat(self) -> Dict[str, str]:
        '''Check to see if the board is alive and kickin'''
        r = requests.get('https://xkcd.com/1906/')
        
        pload = {'username':'Olivia','password':'123'}
        r = requests.post('https://httpbin.org/post',data = pload)
        r_dict = r.json()
        return r_dict['form']

    def calibrate(self):
        '''Calibration routines for the board to reset parameters'''
        pass

    def move(self, x: float, y: float):
        '''Move the arm to (x, y)'''
        pass